// This work is licensed under the Creative Commons Attribution-ShareAlike 3.0 Unported License.
// To view a copy of this license, visit https://creativecommons.org/licenses/by-sa/3.0/ or send a
// letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
// The original file has been modified by Richard Callwood III 2022-Feb-23:
//   The file is upgraded to POV-Ray 3.8.
//   Finishes are completely overhauled, to take advantage of newer, more
//   realistic POV-Ray features.
//   Temporary variables are set with #local.

#ifndef(Gold_Inc_Temp)
#declare Gold_Inc_Temp=version;
#version 3.8;

#ifdef(View_POV_Include_Stack)
#debug "including golds.inc\n"
#end

/*
              Persistence of Vision Raytracer Version 3.8
                      Gold textures
*/

// For diffuse lighting consistent with the rest of your scene, #declare these
// to whatever you use for your #default { finish } before including golds.inc
// or metals.inc; or to force all gold ambients to zero, leave them as is:
#ifndef (Golds_Ambient) #declare Golds_Ambient = rgb 0.0; #end
#ifndef (Golds_Diffuse) #declare Golds_Diffuse = 0.6; #end

#local GoldBase = <1.00, 0.875, 0.575>;  // mine again

// This set shifts the color toward orange by subtracting
// bluegreen from the base color.
#local CVect1 = GoldBase  - <0.00, 0.20, 0.40>;
#local CVect2 = GoldBase  - <0.00, 0.15, 0.30>;
#local CVect3 = GoldBase  - <0.00, 0.10, 0.20>;
#local CVect4 = GoldBase  - <0.00, 0.05, 0.10>;
#local CVect5 = GoldBase  - <0.00, 0.00, 0.00>;

// Cast CVect as an rgb vector
#declare P_Gold1    = rgb CVect1;             // back row
#declare P_Gold2    = rgb CVect2;
#declare P_Gold3    = rgb CVect3;
#declare P_Gold4    = rgb CVect4;
#declare P_Gold5    = rgb CVect5;            // front row

// Reflection levels; reflection { metallic } will handle the colors.
#local R_GoldA =  0.6;        // left column (soft)
#local R_GoldB =  0.7;
#local R_GoldC =  0.8;
#local R_GoldD =  0.9;
#local R_GoldE =  1.0;       // right column (hard)


// Diffuse values
// Calculated as (1 - reflective) * 0.5
#local D_GoldA    = (1 - R_GoldA) * 0.5;
#local D_GoldB    = (1 - R_GoldB) * 0.5;
#local D_GoldC    = (1 - R_GoldC) * 0.5;
#local D_GoldD    = (1 - R_GoldD) * 0.5;
#local D_GoldE    = (1 - R_GoldE) * 0.5;

// Ambient colors, derived from diffuse value
// If Metals_Ambient remains at 0, then all colors will evaluate to 0.
#local A_GoldA    = color D_GoldA * Golds_Ambient / Golds_Diffuse;   // left column (soft)
#local A_GoldB    = color D_GoldB * Golds_Ambient / Golds_Diffuse;
#local A_GoldC    = color D_GoldC * Golds_Ambient / Golds_Diffuse;
#local A_GoldD    = color D_GoldD * Golds_Ambient / Golds_Diffuse;
#local A_GoldE    = color D_GoldE * Golds_Ambient / Golds_Diffuse;  // right column (hard)

// Specular values, derived from reflective and diffuse values
#local S_GoldA    = R_GoldA + D_GoldA * 0.25;
#local S_GoldB    = R_GoldB + D_GoldB * 0.25;
#local S_GoldC    = R_GoldC + D_GoldC * 0.25;
#local S_GoldD    = R_GoldD + D_GoldD * 0.25;
#local S_GoldE    = R_GoldE + D_GoldE * 0.25;


// #debug "\nReflection values:"
// #debug concat("\nR_GoldA = ", str(R_GoldA, 5, 5))
// #debug concat("\nR_GoldB = ", str(R_GoldB, 5, 5))
// #debug concat("\nR_GoldC = ", str(R_GoldC, 5, 5))
// #debug concat("\nR_GoldD = ", str(R_GoldD, 5, 5))
// #debug concat("\nR_GoldE = ", str(R_GoldE, 5, 5))
//
// #debug "\n\nAmbient colors:"
// #debug concat("\nA_GoldA=<", str(A_GoldA.red,   5, 5), "," ,
//                              str(A_GoldA.green, 5, 5),"," ,
//                              str(A_GoldA.blue,  5, 5), ">")
// #debug concat("\nA_GoldB=<", str(A_GoldB.red,   5, 5), "," ,
//                              str(A_GoldB.green, 5, 5),"," ,
//                              str(A_GoldB.blue,  5, 5), ">")
// #debug concat("\nA_GoldC=<", str(A_GoldC.red,   5, 5), "," ,
//                              str(A_GoldC.green, 5, 5),"," ,
//                              str(A_GoldC.blue,  5, 5), ">")
// #debug concat("\nA_GoldD=<", str(A_GoldD.red,   5, 5), "," ,
//                              str(A_GoldD.green, 5, 5),"," ,
//                              str(A_GoldD.blue,  5, 5), ">")
// #debug concat("\nA_GoldE=<", str(A_GoldE.red,   5, 5), "," ,
//                              str(A_GoldE.green, 5, 5),"," ,
//                              str(A_GoldE.blue,  5, 5), ">")
//
//
// #debug "\n\nDiffuse values:"
// #debug concat("\nD_GoldA = ",str(D_GoldA, 5, 5))
// #debug concat("\nD_GoldB = ",str(D_GoldB, 5, 5))
// #debug concat("\nD_GoldC = ",str(D_GoldC, 5, 5))
// #debug concat("\nD_GoldD = ",str(D_GoldD, 5, 5))
// #debug concat("\nD_GoldE = ",str(D_GoldE, 5, 5))
//
// #debug "\n\nSpecular albedo values:"
// #debug concat("\nS_GoldA = ",str(S_GoldA, 5, 5))
// #debug concat("\nS_GoldB = ",str(S_GoldB, 5, 5))
// #debug concat("\nS_GoldC = ",str(S_GoldC, 5, 5))
// #debug concat("\nS_GoldD = ",str(S_GoldD, 5, 5))
// #debug concat("\nS_GoldE = ",str(S_GoldE, 5, 5))
// #debug "\n"

#local M = 1;    //   Metallic amount

//*****Finishes****
// Left column, dullest & darkest
#declare F_MetalA  =
finish {
    brilliance 5/3
    diffuse D_GoldA
    ambient A_GoldA
    emission 0
    reflection { rgb R_GoldA metallic M }
    metallic M
    specular albedo S_GoldA
    roughness 0.002474
}

#declare F_MetalB  =
finish {
    brilliance 5/3
    diffuse D_GoldB
    ambient A_GoldB
    emission 0
    reflection { rgb R_GoldB metallic M }
    metallic M
    specular albedo S_GoldB
    roughness 0.001499
}

#declare F_MetalC  =
finish {
    brilliance 5/3
    diffuse D_GoldC
    ambient A_GoldC
    emission 0
    reflection { rgb R_GoldC metallic M }
    metallic M
    specular albedo S_GoldC
    roughness 0.0009080
}

#declare F_MetalD  =
finish {
    brilliance 5/3
    diffuse D_GoldD
    ambient A_GoldD
    emission 0
    reflection { rgb R_GoldD metallic M }
    metallic M
    specular albedo S_GoldD
    roughness 0.0005502
}

#declare F_MetalE  =
finish {
    brilliance 5/3
    diffuse D_GoldE
    ambient A_GoldE
    emission 0
    reflection { rgb R_GoldE metallic M }
    metallic M
    specular albedo S_GoldE
    roughness 0.0003333
}

//                              GOLDS
#declare T_Gold_1A = texture { pigment { P_Gold1 } finish { F_MetalA } }
#declare T_Gold_1B = texture { pigment { P_Gold1 } finish { F_MetalB } }
#declare T_Gold_1C = texture { pigment { P_Gold1 } finish { F_MetalC } }
#declare T_Gold_1D = texture { pigment { P_Gold1 } finish { F_MetalD } }
#declare T_Gold_1E = texture { pigment { P_Gold1 } finish { F_MetalE } }

#declare T_Gold_2A = texture { pigment { P_Gold2 } finish { F_MetalA } }
#declare T_Gold_2B = texture { pigment { P_Gold2 } finish { F_MetalB } }
#declare T_Gold_2C = texture { pigment { P_Gold2 } finish { F_MetalC } }
#declare T_Gold_2D = texture { pigment { P_Gold2 } finish { F_MetalD } }
#declare T_Gold_2E = texture { pigment { P_Gold2 } finish { F_MetalE } }

#declare T_Gold_3A = texture { pigment { P_Gold3 } finish { F_MetalA } }
#declare T_Gold_3B = texture { pigment { P_Gold3 } finish { F_MetalB } }
#declare T_Gold_3C = texture { pigment { P_Gold3 } finish { F_MetalC } }
#declare T_Gold_3D = texture { pigment { P_Gold3 } finish { F_MetalD } }
#declare T_Gold_3E = texture { pigment { P_Gold3 } finish { F_MetalE } }

#declare T_Gold_4A = texture { pigment { P_Gold4 } finish { F_MetalA } }
#declare T_Gold_4B = texture { pigment { P_Gold4 } finish { F_MetalB } }
#declare T_Gold_4C = texture { pigment { P_Gold4 } finish { F_MetalC } }
#declare T_Gold_4D = texture { pigment { P_Gold4 } finish { F_MetalD } }
#declare T_Gold_4E = texture { pigment { P_Gold4 } finish { F_MetalE } }

#declare T_Gold_5A = texture { pigment { P_Gold5 } finish { F_MetalA } }
#declare T_Gold_5B = texture { pigment { P_Gold5 } finish { F_MetalB } }
#declare T_Gold_5C = texture { pigment { P_Gold5 } finish { F_MetalC } }
#declare T_Gold_5D = texture { pigment { P_Gold5 } finish { F_MetalD } }
#declare T_Gold_5E = texture { pigment { P_Gold5 } finish { F_MetalE } }

//The following #declares are needed for stage_xz.pov

#declare T01 = texture { T_Gold_1A }
#declare T02 = texture { T_Gold_1B }
#declare T03 = texture { T_Gold_1C }
#declare T04 = texture { T_Gold_1D }
#declare T05 = texture { T_Gold_1E }

#declare T06 = texture { T_Gold_2A }
#declare T07 = texture { T_Gold_2B }
#declare T08 = texture { T_Gold_2C }
#declare T09 = texture { T_Gold_2D }
#declare T10 = texture { T_Gold_2E }

#declare T11 = texture { T_Gold_3A }
#declare T12 = texture { T_Gold_3B }
#declare T13 = texture { T_Gold_3C }
#declare T14 = texture { T_Gold_3D }
#declare T15 = texture { T_Gold_3E }

#declare T16 = texture { T_Gold_4A }
#declare T17 = texture { T_Gold_4B }
#declare T18 = texture { T_Gold_4C }
#declare T19 = texture { T_Gold_4D }
#declare T20 = texture { T_Gold_4E }

#declare T21 = texture { T_Gold_5A }
#declare T22 = texture { T_Gold_5B }
#declare T23 = texture { T_Gold_5C }
#declare T24 = texture { T_Gold_5D }
#declare T25 = texture { T_Gold_5E }

#version Gold_Inc_Temp;
#end
